@@ -33,27 +33,27 @@ create_symlink <- function(to, name = "secure_data", ...) {
   # checking inputs ------------------------------------------------------------
   # checking folder name a string of length 1
   if (!rlang::is_string(name)) {
-    ui_oops("Argument {usethis::ui_field(name)} must be a string of length one.")
+    cli::cli_alert_danger("Argument {.field {name}} must be a string of length one.")
     stopifnot(rlang::is_string(name))
   }
 
   # checking if location is an existing folder
   if (fs::is_dir(name)) {
-    ui_oops("{usethis::ui_path(name)} is an existing folder, and symbolic link cannot be placed.")
+    cli::cli_alert_danger("{.file {name}} is an existing folder, and symbolic link cannot be placed.")
     stop()
   }
 
   # checking if a link/file already exists
   if (fs::is_link(name) || fs::is_file(name) || fs::file_exists(name)) {
-    ui_oops("{usethis::ui_path(name)} is an existing symbolic link or file, and a new symbolic link cannot be placed.")
-    ui_oops("Delete the file or update the {usethis::ui_field('name')} argument and re-run {usethis::ui_code('create_symlink()')}.")
+    cli::cli_alert_danger("{.file {name}} is an existing symbolic link or file, and a new symbolic link cannot be placed.")
+    cli::cli_alert_danger("Delete the file or update the {.field name} argument and re-run {.code create_symlink()}.")
     stop()
   }
 
   # checking to argument is a path ---------------------------------------------
   if (!isTRUE(fs::is_dir(to)) || !isTRUE(fs::is_absolute_path(to))) {
-    ui_oops("{usethis::ui_path(to)} is not an existing directory path.")
-    ui_todo("Update the {usethis::ui_field('to')} argument and re-run {usethis::ui_code('create_symlink()')}.")
+    cli::cli_alert_danger("{.file {to}} is not an existing directory path.")
+    cli::cli_ul("Update the {.field to} argument and re-run {.code create_symlink()}.")
     stop()
   }
 
@@ -63,38 +63,39 @@ create_symlink <- function(to, name = "secure_data", ...) {
   msg <- NULL
   if (Sys.info()[["sysname"]] == "Windows") {
     # grabbing drive name of project folder
-    drive_here <- stringr::str_sub(here::here(), 1, 2)
+    drive_here <- substr(here::here(), 1, 2)
 
     # getting list of mapped network drives
     drive_mapped <-
       system("net use", intern = TRUE) %>% # grabbing all mapped drives
-      stringr::str_extract(pattern = "[A-Z]:") %>% # extracting the drive letter
-      purrr::keep(~!is.na(.)) %>% # removing NAs
-      setdiff("C:") # not allowing C: to be selected
+      {regmatches(., gregexpr('[A-Z]:', text = .))} %>% # extracting the drive letter
+      discard(rlang::is_empty) %>% # removing NAs
+      setdiff("C:") %>%
+      unlist()
 
     # saving message to print is warning or error occurs
     if(drive_here %in% drive_mapped) {
       msg <- paste(
-        "It looks like you've attempted to save a symbolic link on a",
-        "mapped network drive. This often causes issues when working in",
-        "Windows. If you encounter an error, consider moving your GitHub",
+        "It looks like you've attempted to save a symbolic link on a\n",
+        "mapped network drive. This often causes issues when working in\n",
+        "Windows. If you encounter an error, consider moving your GitHub\n",
         "repo to your local C: drive, and establishing the link there."
-      ) %>%
-        stringr::str_wrap()
+      )
     }
   }
 
   # wrapping createLink --------------------------------------------------------
-  safe_createLink <- purrr::safely(R.utils::createLink)
+  safe_createLink <- safely(R.utils::createLink)
   result <- safe_createLink(link = here::here(name), target = to, ...)
 
   if (is.null(result$error)) {
-    ui_done(paste0("Symbolic link placed connecting {usethis::ui_path(name)} to\n",
-                   "{usethis::ui_path(to)}"))
+    paste0("Symbolic link placed connecting {.file {name}} to\n",
+           "{.file {to}}") %>%
+      cli::cli_alert_danger()
   }
   else {
     # displaying note about windows and symbolic links if error occurred
-      if(!is.null(msg)) ui_oops(msg)
+      if(!is.null(msg)) cli::cli_alert_danger(msg)
       stop(result$error)
   }
 
